==> mx-welcome_21.04.03mx21.tar.xz: 64/translations/mx-welcome_kk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="kk">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="58"/>
        <location filename="../mainwindow.cpp" line="137"/>
        <location filename="../mainwindow.cpp" line="149"/>
        <source>MX Welcome</source>
        <translation type="unfinished">MX қарсы алу қолданбасы</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="70"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Welcome to MX Linux, a fast, friendly, and stable OS loaded with amazing tools and supported by a great community. &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;MX Linux-ке қош келдіңіз! Ол - жылдам, икемді және тұрақты ОЖ, құрамында пайдалы саймандары және тамаша қоғамдастығы бар. &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="113"/>
        <source>Popular Apps</source>
        <translation type="unfinished">Әйгілі қолданбалар</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="203"/>
        <source>Forums</source>
        <translation type="unfinished">Форумдар</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="280"/>
        <source>Videos</source>
        <translation type="unfinished">Видеолар</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="377"/>
        <source>Contribute</source>
        <translation type="unfinished">Үлес қосу</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="422"/>
        <source>Tweak (Panel, etc...)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="486"/>
        <source>Tools</source>
        <translation type="unfinished">Саймандар</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="512"/>
        <source>Codecs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="544"/>
        <source>Wiki</source>
        <translation type="unfinished">Вики</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="576"/>
        <source>Users Manual</source>
        <translation type="unfinished">Пайдаланушы нұсқаулығы</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="608"/>
        <source>FAQ</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="639"/>
        <source>Show this dialog at start up</source>
        <translation type="unfinished">Бұл сұхбатты жүйеге кірген кезде көрсету</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="704"/>
        <source>About this application</source>
        <translation type="unfinished">Бұл қолданба жөнінде</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="707"/>
        <source>About...</source>
        <translation type="unfinished">Осы туралы...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="714"/>
        <source>Alt+B</source>
        <translation type="unfinished">Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="768"/>
        <source>Quit application</source>
        <translation type="unfinished">Қолданба жұмысын аяқтау</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="771"/>
        <source>Close</source>
        <translation type="unfinished">Жабу</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="778"/>
        <source>Alt+N</source>
        <translation type="unfinished">Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="66"/>
        <source>Default username:  &lt;b&gt;demo&lt;/b&gt; &lt;/p&gt; &lt;p align=&quot;center&quot;&gt;Default demo password:  &lt;b&gt;demo&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="67"/>
        <source>&lt;b&gt;Root&lt;/b&gt; Password:  &lt;b&gt;root&lt;/b&gt;&lt;/p&gt; </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="92"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:14pt; font-weight:600;&quot;&gt;%1 &amp;quot;%2&amp;quot;&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="136"/>
        <source>About MX Welcome</source>
        <translation type="unfinished">MX қарсы алу қолданбасы туралы</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="137"/>
        <source>Version: </source>
        <translation type="unfinished">Нұсқасы:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="138"/>
        <source>Program for displaying a welcome screen in MX Linux</source>
        <translation type="unfinished">MX Linux ішінде қарсы алу экранын көрсетуге арналған қолданба</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="140"/>
        <source>Copyright (c) MX Linux</source>
        <translation type="unfinished">Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="141"/>
        <source>License</source>
        <translation type="unfinished">Лицензиясы</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="142"/>
        <source>Changelog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="143"/>
        <source>Cancel</source>
        <translation type="unfinished">Бас тарту</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="159"/>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>You must run this program as normal user.</source>
        <translation>Бұл бағдарламаны қалыпты пайдаланушы атынан жөнелтуіңіз керек.</translation>
    </message>
</context>
<context>
    <name>mxwelcome</name>
    <message>
        <source>MX Welcome</source>
        <translation type="vanished">MX қарсы алу қолданбасы</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Welcome to MX Linux, a fast, friendly, and stable OS loaded with amazing tools and supported by a great community. &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="vanished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;MX Linux-ке қош келдіңіз! Ол - жылдам, икемді және тұрақты ОЖ, құрамында пайдалы саймандары және тамаша қоғамдастығы бар. &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Popular Apps</source>
        <translation type="vanished">Әйгілі қолданбалар</translation>
    </message>
    <message>
        <source>Forums</source>
        <translation type="vanished">Форумдар</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation type="vanished">Видеолар</translation>
    </message>
    <message>
        <source>Contribute</source>
        <translation type="vanished">Үлес қосу</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation type="vanished">Саймандар</translation>
    </message>
    <message>
        <source>Wiki</source>
        <translation type="vanished">Вики</translation>
    </message>
    <message>
        <source>Users Manual</source>
        <translation type="vanished">Пайдаланушы нұсқаулығы</translation>
    </message>
    <message>
        <source>Show this dialog at start up</source>
        <translation type="vanished">Бұл сұхбатты жүйеге кірген кезде көрсету</translation>
    </message>
    <message>
        <source>About this application</source>
        <translation type="vanished">Бұл қолданба жөнінде</translation>
    </message>
    <message>
        <source>About...</source>
        <translation type="vanished">Осы туралы...</translation>
    </message>
    <message>
        <source>Alt+B</source>
        <translation type="vanished">Alt+B</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation type="vanished">Қолданба жұмысын аяқтау</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Жабу</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation type="vanished">Alt+N</translation>
    </message>
    <message>
        <source>About MX Welcome</source>
        <translation type="vanished">MX қарсы алу қолданбасы туралы</translation>
    </message>
    <message>
        <source>Version: </source>
        <translation type="vanished">Нұсқасы:</translation>
    </message>
    <message>
        <source>Program for displaying a welcome screen in MX Linux</source>
        <translation type="vanished">MX Linux ішінде қарсы алу экранын көрсетуге арналған қолданба</translation>
    </message>
    <message>
        <source>Copyright (c) MX Linux</source>
        <translation type="vanished">Copyright (c) MX Linux</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Лицензиясы</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Бас тарту</translation>
    </message>
</context>
</TS>

==> mx-welcome_21.10.02mx21.tar.xz: 64/translations/mx-welcome_kk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="kk">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="66"/>
        <location filename="../mainwindow.cpp" line="206"/>
        <location filename="../mainwindow.cpp" line="218"/>
        <source>MX Welcome</source>
        <translation type="unfinished">MX қарсы алу қолданбасы</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Welcome to MX Linux, a fast, friendly, and stable OS loaded with amazing tools and supported by a great community. &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="obsolete">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;MX Linux-ке қош келдіңіз! Ол - жылдам, икемді және тұрақты ОЖ, құрамында пайдалы саймандары және тамаша қоғамдастығы бар. &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="349"/>
        <source>Popular Apps</source>
        <translation type="unfinished">Әйгілі қолданбалар</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="578"/>
        <source>Forums</source>
        <translation type="unfinished">Форумдар</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="223"/>
        <source>Videos</source>
        <translation type="unfinished">Видеолар</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="617"/>
        <source>Contribute</source>
        <translation type="unfinished">Үлес қосу</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="323"/>
        <source>Tweak (Panel, etc...)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="643"/>
        <source>Tools</source>
        <translation type="unfinished">Саймандар</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="481"/>
        <source>Codecs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="455"/>
        <source>Wiki</source>
        <translation type="unfinished">Вики</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="397"/>
        <source>Users Manual</source>
        <translation type="unfinished">Пайдаланушы нұсқаулығы</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="203"/>
        <source>Welcome</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="546"/>
        <source>FAQ</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="725"/>
        <source>Install MX Linux</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="781"/>
        <source>Tour</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="816"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="824"/>
        <source>SHORT SYSTEM REPORT:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="831"/>
        <source>DESKTOP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="845"/>
        <source>Quick-System-Info Full Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="855"/>
        <source>Terms of Use</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="872"/>
        <source>The name “MX Linux” is covered by Linux Foundation Sublicense No. 20140605-0483. We develop software that is covered by a free license that can be examined in the Wiki list. We also include software developed by others that is under a free license.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="882"/>
        <source>MX VERSION</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="889"/>
        <source>DEBIAN VERSION:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="896"/>
        <source>SUPPORTED UNTIL:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="916"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Noto Sans&apos;; font-size:10.5pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="950"/>
        <source>Show this dialog at start up</source>
        <translation type="unfinished">Бұл сұхбатты жүйеге кірген кезде көрсету</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="112"/>
        <source>About this application</source>
        <translation type="unfinished">Бұл қолданба жөнінде</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="115"/>
        <source>About...</source>
        <translation type="unfinished">Осы туралы...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="122"/>
        <source>Alt+B</source>
        <translation type="unfinished">Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="80"/>
        <source>Quit application</source>
        <translation type="unfinished">Қолданба жұмысын аяқтау</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="83"/>
        <source>Close</source>
        <translation type="unfinished">Жабу</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="90"/>
        <source>Alt+N</source>
        <translation type="unfinished">Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="79"/>
        <source>User demo, password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="80"/>
        <source>Superuser root, password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="126"/>
        <location filename="../mainwindow.cpp" line="142"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="155"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:14pt; font-weight:600;&quot;&gt;%1 &amp;quot;%2&amp;quot;&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="205"/>
        <source>About MX Welcome</source>
        <translation type="unfinished">MX қарсы алу қолданбасы туралы</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="206"/>
        <source>Version: </source>
        <translation type="unfinished">Нұсқасы:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="207"/>
        <source>Program for displaying a welcome screen in MX Linux</source>
        <translation type="unfinished">MX Linux ішінде қарсы алу экранын көрсетуге арналған қолданба</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="209"/>
        <source>Copyright (c) MX Linux</source>
        <translation type="unfinished">Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="210"/>
        <source>License</source>
        <translation type="unfinished">Лицензиясы</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="211"/>
        <source>Changelog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="212"/>
        <source>Cancel</source>
        <translation type="unfinished">Бас тарту</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="228"/>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>You must run this program as normal user.</source>
        <translation>Бұл бағдарламаны қалыпты пайдаланушы атынан жөнелтуіңіз керек.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="44"/>
        <source>This tool displays a welcome screen with two tabs.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="47"/>
        <source>Start with About tab selected. The About tab provides basic information about the current MX Linux version, the user&apos;s hardware, and access to a full system report.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>Run a test mode.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>mxwelcome</name>
    <message>
        <source>MX Welcome</source>
        <translation type="vanished">MX қарсы алу қолданбасы</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Welcome to MX Linux, a fast, friendly, and stable OS loaded with amazing tools and supported by a great community. &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="vanished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;MX Linux-ке қош келдіңіз! Ол - жылдам, икемді және тұрақты ОЖ, құрамында пайдалы саймандары және тамаша қоғамдастығы бар. &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Popular Apps</source>
        <translation type="vanished">Әйгілі қолданбалар</translation>
    </message>
    <message>
        <source>Forums</source>
        <translation type="vanished">Форумдар</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation type="vanished">Видеолар</translation>
    </message>
    <message>
        <source>Contribute</source>
        <translation type="vanished">Үлес қосу</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation type="vanished">Саймандар</translation>
    </message>
    <message>
        <source>Wiki</source>
        <translation type="vanished">Вики</translation>
    </message>
    <message>
        <source>Users Manual</source>
        <translation type="vanished">Пайдаланушы нұсқаулығы</translation>
    </message>
    <message>
        <source>Show this dialog at start up</source>
        <translation type="vanished">Бұл сұхбатты жүйеге кірген кезде көрсету</translation>
    </message>
    <message>
        <source>About this application</source>
        <translation type="vanished">Бұл қолданба жөнінде</translation>
    </message>
    <message>
        <source>About...</source>
        <translation type="vanished">Осы туралы...</translation>
    </message>
    <message>
        <source>Alt+B</source>
        <translation type="vanished">Alt+B</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation type="vanished">Қолданба жұмысын аяқтау</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Жабу</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation type="vanished">Alt+N</translation>
    </message>
    <message>
        <source>About MX Welcome</source>
        <translation type="vanished">MX қарсы алу қолданбасы туралы</translation>
    </message>
    <message>
        <source>Version: </source>
        <translation type="vanished">Нұсқасы:</translation>
    </message>
    <message>
        <source>Program for displaying a welcome screen in MX Linux</source>
        <translation type="vanished">MX Linux ішінде қарсы алу экранын көрсетуге арналған қолданба</translation>
    </message>
    <message>
        <source>Copyright (c) MX Linux</source>
        <translation type="vanished">Copyright (c) MX Linux</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Лицензиясы</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Бас тарту</translation>
    </message>
</context>
</TS>
